summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDirk-Jan C. Binnema <djcb@djcbsoftware.nl>2021-06-17 22:22:00 +0300
committerGitHub <noreply@github.com>2021-06-17 22:22:00 +0300
commit7034556ab4d7b0fc36eda93ab4b7a5370fdbea83 (patch)
tree21dcd5ffd7cbb5575476e0249d527f65ed97eb54
parent6ddfc61c8d35dcfb0099f2b7a44597b0eb247a15 (diff)
parent2f251209e3bd7e5b43c4384e95f183ec761b8416 (diff)
Merge pull request #2034 from thierryvolpiatto/remove_marked_overlays
Only remove mark overlays in `mu4e-mark-at-point`
-rw-r--r--mu4e/mu4e-mark.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/mu4e/mu4e-mark.el b/mu4e/mu4e-mark.el
index 11e23e4..7e2b6c1 100644
--- a/mu4e/mu4e-mark.el
+++ b/mu4e/mu4e-mark.el
@@ -266,8 +266,8 @@ The following marks are available, and the corresponding props:
;; update the hash -- remove everything current, and if add the new
;; stuff, unless we're unmarking
(remhash docid mu4e~mark-map)
- ;; remove possible overlays
- (remove-overlays (line-beginning-position) (line-end-position))
+ ;; remove possible mark overlays
+ (remove-overlays (line-beginning-position) (line-end-position) 'mu4e-mark t)
;; now, let's set a mark (unless we were unmarking)
(unless (eql mark 'unmark)
(puthash docid (cons mark target) mu4e~mark-map)
@@ -282,6 +282,8 @@ The following marks are available, and the corresponding props:
(mu4e~headers-goto-docid docid t)))
(overlay (make-overlay start (+ start (length targetstr)))))
(overlay-put overlay 'display targetstr)
+ (overlay-put overlay 'mu4e-mark t)
+ (overlay-put overlay 'evaporate t)
docid)))))))
(defun mu4e~mark-get-move-target ()